==> devspaces-dashboard-rhel8-container-3.2-30.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-frontend/src/store/Plugins/devWorkspacePlugins/__tests__/selectors.spec.ts <==
/*
 * Copyright (c) 2018-2021 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import { MockStoreEnhanced } from 'redux-mock-store';
import { ThunkDispatch } from 'redux-thunk';
import devfileApi from '../../../../services/devfileApi';
import { FakeStoreBuilder } from '../../../__mocks__/storeBuilder';
import * as store from '..';
import { AppState } from '../../..';
import { selectDwPlugins, selectDwPluginsList, selectDwDefaultEditorError } from '../selectors';

const url = 'devworkspace-devfile-location';

describe('dwPlugins selectors', () => {
  const plugins = {
    'plugin-location-1': {
      url,
      plugin: {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-1',
        },
      } as devfileApi.Devfile,
    },
    'plugin-location-2': {
      url,
      plugin: {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-2',
        },
      } as devfileApi.Devfile,
    },
    'plugin-location-3': {
      url,
      error: 'unexpected error',
    },
  };

  it('should return all plugins and errors', () => {
    const fakeStore = new FakeStoreBuilder()
      .withDwPlugins(plugins, false, 'default editor fetching error')
      .build() as MockStoreEnhanced<
      AppState,
      ThunkDispatch<AppState, undefined, store.KnownAction>
    >;
    const state = fakeStore.getState();

    const expectedPlugins = plugins;
    const selectedPlugins = selectDwPlugins(state);
    expect(selectedPlugins).toEqual(expectedPlugins);
  });

  it('should return array of plugins', () => {
    const fakeStore = new FakeStoreBuilder()
      .withDwPlugins(plugins, false, 'default editor fetching error')
      .build() as MockStoreEnhanced<
      AppState,
      ThunkDispatch<AppState, undefined, store.KnownAction>
    >;
    const state = fakeStore.getState();

    const expectedPlugins = [
      {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-1',
        },
      } as devfileApi.Devfile,
      {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-2',
        },
      } as devfileApi.Devfile,
    ];
    const selectedPlugins = selectDwPluginsList(state);
    expect(selectedPlugins).toEqual(expectedPlugins);
  });

  it('should return an error related to default editor fetching', () => {
    const fakeStore = new FakeStoreBuilder()
      .withDwPlugins(plugins, false, 'default editor fetching error')
      .build() as MockStoreEnhanced<
      AppState,
      ThunkDispatch<AppState, undefined, store.KnownAction>
    >;
    const state = fakeStore.getState();

    const selectedError = selectDwDefaultEditorError(state);
    expect(selectedError).toEqual('default editor fetching error');
  });
});

==> devspaces-dashboard-rhel8-container-3.5-24.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-frontend/src/store/Plugins/devWorkspacePlugins/__tests__/selectors.spec.ts <==
/*
 * Copyright (c) 2018-2021 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import { MockStoreEnhanced } from 'redux-mock-store';
import { ThunkDispatch } from 'redux-thunk';
import devfileApi from '../../../../services/devfileApi';
import { FakeStoreBuilder } from '../../../__mocks__/storeBuilder';
import * as store from '..';
import { AppState } from '../../..';
import { selectDwPlugins, selectDwPluginsList, selectDwDefaultEditorError } from '../selectors';

const url = 'devworkspace-devfile-location';

describe('dwPlugins selectors', () => {
  const plugins = {
    'plugin-location-1': {
      url,
      plugin: {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-1',
        },
      } as devfileApi.Devfile,
    },
    'plugin-location-2': {
      url,
      plugin: {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-2',
        },
      } as devfileApi.Devfile,
    },
    'plugin-location-3': {
      url,
      error: 'unexpected error',
    },
  };

  it('should return all plugins and errors', () => {
    const fakeStore = new FakeStoreBuilder()
      .withDwPlugins({ plugins, defaultEditorError: 'default editor fetching error' }, false)
      .build() as MockStoreEnhanced<
      AppState,
      ThunkDispatch<AppState, undefined, store.KnownAction>
    >;
    const state = fakeStore.getState();

    const expectedPlugins = plugins;
    const selectedPlugins = selectDwPlugins(state);
    expect(selectedPlugins).toEqual(expectedPlugins);
  });

  it('should return array of plugins', () => {
    const fakeStore = new FakeStoreBuilder()
      .withDwPlugins({ plugins, defaultEditorError: 'default editor fetching error' }, false)
      .build() as MockStoreEnhanced<
      AppState,
      ThunkDispatch<AppState, undefined, store.KnownAction>
    >;
    const state = fakeStore.getState();

    const expectedPlugins = [
      {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-1',
        },
      } as devfileApi.Devfile,
      {
        schemaVersion: '2.1.0',
        metadata: {
          name: 'void-sample-2',
        },
      } as devfileApi.Devfile,
    ];
    const selectedPlugins = selectDwPluginsList(state);
    expect(selectedPlugins).toEqual(expectedPlugins);
  });

  it('should return an error related to default editor fetching', () => {
    const fakeStore = new FakeStoreBuilder()
      .withDwPlugins({ plugins, defaultEditorError: 'default editor fetching error' }, false)
      .build() as MockStoreEnhanced<
      AppState,
      ThunkDispatch<AppState, undefined, store.KnownAction>
    >;
    const state = fakeStore.getState();

    const selectedError = selectDwDefaultEditorError(state);
    expect(selectedError).toEqual('default editor fetching error');
  });
});
